EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerImages_GetImagesWithAlternativeTags',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'DockerImages_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the Docker image tags for the specified repository.'
GO

IF OBJECT_ID('[DockerImages_GetImagesWithAlternativeTags]') IS NOT NULL DROP PROCEDURE [DockerImages_GetImagesWithAlternativeTags]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_GetImagesWithAlternativeTags]
(
	@Feed_Id INT = NULL,
    @PublishedBefore_Date DATETIME = NULL,	
	@DockerImages_Count INT = NULL
)
AS
BEGIN

SET NOCOUNT ON

    IF @DockerImages_Count IS NOT NULL
        SET ROWCOUNT @DockerImages_Count

	SELECT DI.[Feed_Id]
			,DI.[Repository_Name]
			,DI.[Image_Digest]
			,DI.[ManifestJson_Bytes]
			,DI.[Download_Count]
			,DI.[Published_Date]
			,DI.[Cached_Indicator]
			,DI.[ContainerConfigBlob_Id]
			,DI.[DockerImage_Id]
			,DI.[DockerRepository_Id]
			,DI.[ImageType_Code]
			,DI.[Canonical_Tag_Name]
			,DI.[LastDownload_Date]
			,DI.[ContainerConfigBlob_Digest]
			,DI.[Vulnerabilities_Severity_Code]
			,DI.[Vulnerabilities_Unassessed_Indicator]
			,DI.[Vulnerabilities_Count]
			,DI.[AssessedVulnerabilities_Count]
			,COUNT(DRT.Tag_Name) as AlternativeTags_Count
	  FROM [DockerRepositoryTags_Extended] DRT
		INNER JOIN [DockerImages_Extended] DI ON DRT.DockerImage_Id = DI.DockerImage_Id
	 WHERE (@Feed_Id IS NULL OR DRT.[Feed_Id] = @Feed_Id)
       AND (@PublishedBefore_Date IS NULL OR DRT.[Published_Date] < @PublishedBefore_Date)
	   GROUP BY DI.[Feed_Id]
				,DI.[Repository_Name]
				,DI.[Image_Digest]
				,DI.[ManifestJson_Bytes]
				,DI.[Download_Count]
				,DI.[Published_Date]
				,DI.[Cached_Indicator]
				,DI.[ContainerConfigBlob_Id]
				,DI.[DockerImage_Id]
				,DI.[DockerRepository_Id]
				,DI.[ImageType_Code]
				,DI.[Canonical_Tag_Name]
				,DI.[LastDownload_Date]
				,DI.[ContainerConfigBlob_Digest]
				,DI.[Vulnerabilities_Severity_Code]
				,DI.[Vulnerabilities_Unassessed_Indicator]
				,DI.[Vulnerabilities_Count]
			,DI.[AssessedVulnerabilities_Count]
	   HAVING COUNT(DRT.Tag_Name) > 1

END
GO

GRANT EXECUTE ON [DockerImages_GetImagesWithAlternativeTags] TO [ProGetUser_Role]
GO